
local maxLength = 18
local octaves = 5
local holdingLength = 5
local noteCount = 16

local spacing = .47625+.05

local lengths = {}
local base = maxLength
local totalLength = 0
for i=1,noteCount do
	local length = maxLength/2^((i-1)*7/12)
	while length*2 <= maxLength do
		length=length*2
	end
	local o = octaves-1
	while o >= 0 do
		local piece = length/2^o+holdingLength
		totalLength=totalLength+piece
		table.insert(lengths,piece)
		o=o-1
	end
end

totalLength = totalLength/30.48

local font = love.graphics.newFont(30)
love.graphics.setFont(font)
local fontHeight = font:getHeight(')')

local scaleY,space
function love.resize(x,y)
	love.height = x
	love.width = x
	scaleY = (y-fontHeight)/(maxLength+holdingLength)
	space = spacing
end
love.window.setMode(600,800,{resizable=true})
love.resize(600,800)

local lg = love.graphics
local lm = love.mouse
local la = love.audio
local mouseX,mouseY,index = 0,0,0
local oldIndex=0
local dist=0
function love.mousemoved(mx,my)
	mouseX,mouseY=mx,my
	local dx,dy = mx-(index or 1)*space,my-(lengths[index or 1] or 1)*scaleY
	dist = math.sqrt(dx*dx+dy*dy)
	for i,len in ipairs(lengths) do
		local dx,dy = mx-i*space,my-len*scaleY
		local newDist = math.sqrt(dx*dx+dy*dy)
		if newDist<dist then
			index = i
			dist = index
		end
	end
	--index = math.min(math.floor(mouseX/space)+1,#lengths)
	if lm.isDown(1) and oldIndex~=index then
		play()
	end
end

function love.mousepressed(mx,my,button)
	play()
end

local sounds = {}
function play()
	local foundASound = false
	for i,sound in ipairs(sounds) do
		if not sound:isPlaying() then
			playSound(sound)
			foundASound = true
			break
		end
	end
	if not foundASound then
		playSound(la.newSource('/note.wav','static'))
	end
	oldIndex=index
end
function playSound(sound)
	sound:setPitch(0.0625/((lengths[index]-holdingLength)/maxLength))
	sound:play()
end

function love.draw()
    spacing = love.width / (octaves*noteCount)
	lg.setColor(.5,.3,.4)
	lg.circle('fill',index*space,(lengths[index] or 10)*scaleY,dist or 10)
	lg.setColor(.4,.5,.6)
	for i,l in ipairs(lengths) do
		local x = (i-1)* space
		lg.rectangle('fill',x,0,space-1,l*scaleY)
	end
	lg.setColor(0,0,0)
	local y = holdingLength* scaleY
	lg.line(0,y,love.width,y)
	local len = lengths[index]
	if len then
		lg.setColor(.6,.5,.4)
		local x = (index-1)* space
		lg.rectangle('fill',x,0,space-2,len*scaleY)
		lg.setColor(1,.9,.8)
		lg.print(len,math.min(mouseX,love.width-font:getWidth(len)),mouseY)
	end
	lg.setColor(1,1,1)
	lg.print(totalLength..' feet of tine needed')
end

-- get ride of the way that text editor inersts text
